function [ContactProg]=FindContact(app)
%% Use a single pole low-pass filter with normalized weight k1 applied to the newest datapoint

if(app.Controller_SearchingForZeroGap)
    ContactType=false;%Zero gap
else
    ContactType=true;%sample contact
end

if(ContactType)%sample contact
    Reset_Limit=sprintf('FL0\r');%don't allow position to exceed zero gap - protect the load cell!
else%zero gap
    Reset_Limit=sprintf('FL2147483647\r');%largest possible value effectively disables limit switch when searching for zero gap
end

if(ContactType)%finding contact with sample
    disp('Searching for sample contact...')
    contact_force=get(app.ContactForceEditField,'Value')*1e3;%mN to uN
    contact_velocity=abs(round(MicronsToCounts(get(app.ContactVelocityEditField,'Value'))));%microns/s to count/s
else
    disp('Finding zero gap...')
    contact_force=get(app.ZeroGapForceEditField,'Value')*1e3;%mN to uN
    contact_velocity=abs(round(MicronsToCounts(get(app.ZeroGapVelocityEditField,'Value'))));%microns/s to count/s
end

if(contact_velocity<2),contact_velocity=2;end%resolution of SP is 2 counts/s, otherwise motor is effectively stopped

%% Specify the jog program
ContactProg1=sprintf([  '#contact\r',...
                        Reset_Limit,...
                        'CB2;cont=0\r',...%reset bit 2 which is indicator of contact
                        'cforce=',num2str(contact_force),'\r',...
                        'cvel=',num2str(contact_velocity),'\r',...
                        'AC 1024\r',...%minimize acceleration to prevent false contact due to initial jerk
                        'DC 2000000\r',...%allow fast stop upon contact
                        'SH\r',...
                        'JGcvel\r',...
                        'BG\r',...
                        'WT1000\r',...%wait 1 second to avoid jerk issues
                        '#cloop\r',...
                        'IF(_ZAA>=cforce)\r',...%ZAA has units of micrograms
                        'STA\r',...%used to be AB1, but that stopped more slowly or jerked backwards. This works.
                        'SB2\r',...%set contact bit for data analysis purposes
                        'AM\r']);%need this to ensure motion has stopped prior to doing subsequent commands (learned the hard way).

%% Specify the stop condition
if(ContactType==0)%zero gap
    ContactProg2=sprintf([  'DPA=0\r',...%set this as the reference position (i.e. z=0)
                            'FL0\r',...%set software forward limit corresponding to zero gap
                            'cont=1\r',...
                            'MG"ZERO_GAP"\r',...
                            'ENDIF\r',...
                            'JP#cloop,cont=0\r',...
                            'EN\r\r']);
                        
else%finding contact w/ sample
    ContactProg2=sprintf([	'height=_TPA\r',...%set contact height equal to current absolute position
                            'MG"CONTACT"\r',...
                            'cont=1\r',...%indicate contact found
                            'ENDIF\r',...
                            'JP#cloop,cont=0\r',...
                            'EN\r\r']);%,...
end

ContactProg=[ContactProg1 ContactProg2];
